package com.hyp.web.controller.manager;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.convert.Convert;
import com.hyp.common.core.domain.model.LoginUser;
import com.hyp.common.exception.ServiceException;
import com.hyp.common.utils.SecurityUtils;
import com.hyp.system.domain.RewApplyInfoList;
import com.hyp.system.domain.dto.ApplyInfoListDTO;
import com.hyp.system.domain.vo.ApplyInfoListVO;
import com.hyp.system.service.RewApplyInfoListService;
import com.hyp.system.service.RewScoreInfoService;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

/**
 * packageName com.hyp.web.controller.manager
 *
 * @author wangxy
 * @version JDK 8
 * @className RewApplyInfoListManager
 * @date 2024/4/11
 * @description 申请
 */
@Component
public class ApplyInfoListManager {

    @Resource
    private RewApplyInfoListService applyInfoListService;

    @Resource
    private RewScoreInfoService scoreInfoService;




    public List<ApplyInfoListVO> selectApplyInfoList(ApplyInfoListDTO applyInfoListDTO){
        return applyInfoListService.selectApplyInfoList(applyInfoListDTO);
    }


    /**
     *
     *  生成applyId
     * @param applyType
     * @return com.hyp.system.domain.vo.ApplyInfoListVO
     */
    @Transactional(rollbackFor = Exception.class)
    public ApplyInfoListVO getApplyId(String applyType){
        LoginUser loginUser = SecurityUtils.getLoginUser();
         List<RewApplyInfoList> list = applyInfoListService.lambdaQuery()
                .eq(RewApplyInfoList::getApplyType, applyType)
                 .eq(RewApplyInfoList::getCreateId, loginUser.getUserId())
                 .list();
         if(CollUtil.isNotEmpty(list)){
             throw new ServiceException("该用户已申请，不能重复申请！");
         }
        RewApplyInfoList applyInfoList = new RewApplyInfoList();
        applyInfoList.setApplyType(applyType);
        applyInfoList.setApplyStatus(0);
        applyInfoList.setCreateId(loginUser.getUserId());
        applyInfoList.setCreateBy(loginUser.getUsername());
        applyInfoList.setUpdateTime(new Date());
        applyInfoList.setCreateTime(new Date());
        applyInfoListService.save(applyInfoList);
        return Convert.convert(ApplyInfoListVO.class, applyInfoList);
    }


}
